@@ -2,7 +2,7 @@
 package MRTG_lib;
 
 ###################################################################
-# MRTG 2.10.14  Support library MRTG_lib.pm
+# MRTG 2.11.0  Support library MRTG_lib.pm
 ###################################################################
 # Created by Tobias Oetiker <oetiker@ee.ethz.ch>
 #            and Dave Rand <dlr@bungi.com>
@@ -17,7 +17,7 @@ package MRTG_lib;
 
 require 5.005;
 use strict;
-use SNMP_util "1.03";
+use SNMP_util "1.04";
 use vars qw($OS $SL $PS @EXPORT @ISA $VERSION %timestrpospattern);
 my %mrtgrules;
 
@@ -27,6 +27,10 @@ BEGIN {
         $OS = 'NT';
         $SL = '\\';
         $PS = ';';
+    } elsif ( $^O =~ /^NetWare$/i ) {
+	$OS = 'NW';
+	$SL = '/';
+	$PS = ';';
     } elsif ( $^O =~ /^VMS$/i ) {
         $OS = 'VMS';
         $SL = '.';
@@ -50,7 +54,7 @@ require Exporter;
 	     populateconfcache readconfcache writeconfcache
 	     v4onlyifnecessary);
 
-$VERSION = 2.100001;
+$VERSION = 2.100015;
 
 %timestrpospattern =
       (
@@ -124,6 +128,9 @@ $VERSION = 2.100001;
        'runasdaemon' =>
        [sub{1}, sub{"Internal Error"}],
 
+       'nodetach' =>
+       [sub{1}, sub{"Internal Error"}],
+
        'maxage' =>
        [sub{(($_[0] =~ /^[0-9]+$/) and ($_[0] > 0)) },
         sub{"$_[0] must be a Number bigger than 0"}],
@@ -576,10 +583,10 @@ sub cfgcheck ($$$$) {
     # duplicate entries in @$target.
     my $targIndex = { };
     my $error="no";
-    my(@known_options) = qw(growright bits noinfo absolute gauge nopercent avgpeak
+    my(@known_options) = qw(growright bits noinfo absolute gauge nopercent avgpeak derive
 			    integer perhour perminute transparent dorelpercent 
 			    unknaszero withzeroes noborder noarrow noi noo
-			    nobanner nolegend pngdate printrouter);
+			    nobanner nolegend logscale secondmean pngdate printrouter);
 
     snmpmapOID('hrSystemUptime' => '1.3.6.1.2.1.25.1.1');
 
@@ -798,6 +805,10 @@ sub cfgcheck ($$$$) {
                     $error="yes";
                 }
             }
+	    if ($rcfg->{'options'}{derive}{$rou} and not $cfg->{logformat} eq 'rrdtool'){
+		    warn ("WARNING: Option[$rou]: \"derive\" works only with rrdtool logformat\n");
+		    $error="yes";
+	    }
         }
         #
         # Check out routeruptime definition
